@@ -12,6 +12,8 @@
  * 2001/11/29 - EvB - Added some attributes from RAD-ATR as well as the
  * 		      four 'anonymous' ones from space INTERNAL
  * 2002/03/20 - EvB - Added limit on shared send queue length
+ * 2003/06/23 - EvB - Increased C_MAX_MSGSIZE
+ * 2003/06/23 - EvB - Added constants needed for accept/reject/acctresp ops.
  */
 
 
@@ -27,7 +29,7 @@
 
 /* Maximum interface message size (ascii or binary) */
 
-#define C_MAX_MSGSIZE		8192	/* Seems reasonable */
+#define C_MAX_MSGSIZE		16384	/* Seems reasonable */
 
 
 /* Maximum jobs on an interface's shared send queue */
@@ -62,10 +64,15 @@
 
 #define C_DS_RAD_PKT		1	/* Space that holds whole packet */
 
-#define C_DI_CODE		1	/* Code (in above space) */
+#define C_DI_CODE		0	/* Code (in above space) */
+#define C_DI_IDENTIFIER		1	/* Identifier (in above spc) */
 #define C_DI_AUTHENTICATOR	3	/* Authenticator (in above spc) */
 					/* We sign packet here after encoding */
 
+#define C_DV_CODE_ACCEPT	2	/* Values for RAD-Code */
+#define C_DV_CODE_REJECT	3
+#define C_DV_CODE_ACCTRESP	5
+
 #define C_DS_INTERNAL		100	/* Space that holds internal attrs */
 
 #define C_DI_TIMESTAMP		10	/* Timestamp of request */
