@@ -142,9 +142,9 @@ struct meta_item {
 	META_ORD vnd;				/* Vendor, only for AV items */
 	META_NAME name;
 
-	char len_ofs, len_size, len_adj;
-	char val_ofs, val_size, val_type;
-	char nodec, noenc;			/* flags */
+	char len_ofs, len_size, len_adj, resv0;
+	char val_ofs, val_size, val_type, resv1;
+	char nodec, noenc, keeprej, keepacct;	/* flags */
 	META_SPC *spc;				/* The space this is part of */
 	META_SPC *subspace;			/* The space inside this item */
 
@@ -238,7 +238,8 @@ META_ITEM *meta_additem(META *m, META_SPC *s,
 		META_ORD nr, META_ORD vnd, char *name,
 		char len_ofs, char len_size, char len_adj,
 		char val_ofs, char val_size, char val_type,
-                META_SPC *subspace, char nodec, char noenc);
+                META_SPC *subspace, char nodec, char noenc,
+		char keeprej, char keepacct);
 META_ITEM *meta_getitembynr(META *m, META_SPC *s, META_ORD nr, META_ORD vnd);
 META_ITEM *meta_getitembyname(META *m, META_SPC *s, char *name, META_ORD vnd);
 META_ITEM *meta_getitembyspec(META *m, char *spec);
