@@ -242,7 +242,7 @@ int proc_start(PROC *p, time_t t)
 		}
 
 		/* Set the working directory */
-		if (chdir(p->cwd) == -1) {
+		if (p->cwd && chdir(p->cwd) == -1) {
 			msg(F_PROC, L_ERR, "proc_run: ERROR: Could not chdir "
 					   "to '%s': %s!\n",
 			    p->cwd, strerror(errno));
