@@ -86,11 +86,14 @@ typedef struct stdop {
 /* The standard operators we know */
 
 
-#define STDOP_CNT	67
+#define STDOP_CNT	73
 
 static STDOP stdops[STDOP_CNT] = {
 	{ "halt",	 NON, 32, L,   ANY, NON,   INT, OP_HALT },
 	{ "abort",	 NON, 32, L,   ANY, NON,   INT, OP_ABORT },
+	{ "accept",	 NON, 32, L,   ANY, NON,   INT, OP_ACCEPT },
+	{ "reject",	 NON, 32, L,   ANY, NON,   INT, OP_REJECT },
+	{ "acctresp",	 NON, 32, L,   ANY, NON,   INT, OP_ACCTRESP },
 	{ "delall",	 NON, 32, L,   ANY, ANY,   INT, OP_DELALLAV },
 	{ "del",	 NON, 32, L,   ANY, ANY,   INT, OP_DELAV },
 	{ "moveall",	 NON, 32, L,   ANY, ANY,   INT, OP_MOVEALLAV },
@@ -109,9 +112,12 @@ static STDOP stdops[STDOP_CNT] = {
 	{ "todec",	 ANY, 30, L,   INT, NON,   STR, OP_ORD2DECSTR },
 	{ "tohex",	 ANY, 30, L,   INT, NON,   STR, OP_ORD2HEXSTR },
 	{ "toraw",	 ANY, 30, L,   INT, NON,   STR, OP_ORD2RAWSTR },
+	{ "exists",	 ANY, 30, L,   ANY, NON,   INT, OP_EXISTS },
 	{ "~",		 NON, 28, R,   ANY, INT,   INT, OP_NOT },
 	{ "-",		 NON, 28, R,   ANY, INT,   INT, OP_NEG },
-	{ "!",		 NON, 28, R,   ANY, ANY,   INT, OP_NO },
+	{ "!",		 NON, 28, R,   ANY, ANY,   INT, OP_BOOLNOT },
+	{ "not",	 NON, 28, R,   ANY, ANY,   INT, OP_BOOLNOT },
+	{ "no",		 NON, 28, R,   ANY, ANY,   INT, OP_BOOLNOT },
 	{ "md5",	 NON, 28, R,   ANY, STR,   STR, OP_MD5 },
 	{ "hex",	 NON, 28, R,   ANY, STR,   STR, OP_HEX },
 	{ "*",		 ANY, 25, L,   INT, INT,   INT, OP_MUL },
