@@ -63,6 +63,9 @@
 
 #define OP_HALT		0x00000
 #define OP_ABORT	0xffff0
+#define OP_ACCEPT	0xf0000
+#define OP_REJECT	0xf0010
+#define OP_ACCTRESP	0xf0020
 #define OP_NOP		0x00010
 #define OP_PUSHINT	0x00020
 #define OP_PUSHSTR	0x00030
@@ -124,17 +127,18 @@
 #define OP_ORD2DATSTR	0x003d1		/* YYYYMMDDhhmmss */
 #define OP_ORD2DFMSTR	0x003e2		/* formatted date using strftime() */
 
-#define OP_NO		0x00401		/* boolean not, returns 1 when false */
-#define OP_JMPZ		0x00411		/* jmp if zero (false) */
-#define OP_JMPNZ	0x00421		/* jmp if nonzero (true) */
+#define OP_EXISTS	0x00401		/* returns 1 if resolved */
+#define OP_BOOLNOT	0x00411		/* boolean not, returns 1 when false */
+#define OP_JMPZ		0x00421		/* jmp if zero (false) */
+#define OP_JMPNZ	0x00431		/* jmp if nonzero (true) */
 
-#define OP_ADDAV	0x00436		/* add referenced AV based on term */
-#define OP_REPLACEAV	0x00446		/* replace referenced AV with term */
-#define OP_DELAV	0x00455		/* delete referenced AV (see code) */
-#define OP_DELALLAV	0x00460		/* delete all inst. of referenced AV */
-#define OP_MOVEALLAV	0x00470		/* copy all inst. of referenced AV */
+#define OP_ADDAV	0x00486		/* add referenced AV based on term */
+#define OP_REPLACEAV	0x00496		/* replace referenced AV with term */
+#define OP_DELAV	0x004a5		/* delete referenced AV (see code) */
+#define OP_DELALLAV	0x004b0		/* delete all inst. of referenced AV */
+#define OP_MOVEALLAV	0x004c0		/* copy all inst. of referenced AV */
 
-#define OP_CALLIFACE	0x00480		/* call external interface */
+#define OP_CALLIFACE	0x00500		/* call external interface */
 
 
 /* Request and Reply list indexes for head and tail arrays */
