@@ -23,6 +23,8 @@
  * 		      constant associated with that string attribute.
  * 2002/04/23 - EvB - Sanitized conversion operators
  * 		    - Fixed small ! operator behaviour bug on strings
+ * 2003/12/30 - EvB - Added EXISTS instruction that tests for a resolved
+ * 		      attribute reference
  */
 
 char langvm[] = "LANGVM - Copyright (C) 2001 Emile van Bergen.";
@@ -184,14 +186,16 @@ int vm_run(VM *vm)
 					/* First: take first match forwards */
 					avlst = vm->head[av->flags & AV_USEREP];
 					for( ; 
-					    avlst && avlst->i != av->i;
+					    avlst && (avlst->i != av->i ||
+						      avlst->flags & AV_DEL);
 					    avlst = avlst->next);
 				}
 				else {
 					/* Last: take first match backwards */
 					avlst = vm->tail[av->flags & AV_USEREP];
 					for( ; 
-					    avlst && avlst->i != av->i;
+					    avlst && (avlst->i != av->i ||
+						      avlst->flags & AV_DEL);
 					    avlst = avlst->prev);
 				}
 
@@ -217,9 +221,38 @@ int vm_run(VM *vm)
 		   */
 
 		  case OP_HALT:
-			ret = VM_HALTED; break;
+			ret = VM_HALTED; 
+			break;
 		  case OP_ABORT:
-			ret = VM_ABORTED; break;
+			ret = VM_ABORTED; 
+			break;
+		  case OP_ACCEPT:
+			for(av = vm->head[VM_REP]; av; av = av->next) {
+				if (av->i->spc->nr == C_DS_RAD_PKT && av->i->nr == C_DI_CODE) 
+					av->l = C_DV_CODE_ACCEPT;
+			}
+			ret = VM_HALTED; 
+			break;
+		  case OP_REJECT:
+			for(av = vm->head[VM_REP]; av; av = av->next) {
+				if (av->i->spc->nr == C_DS_RAD_PKT && av->i->nr == C_DI_CODE) 
+					av->l = C_DV_CODE_REJECT;
+				if (av->i->spc->nr != C_DS_RAD_ATR || av->i->keeprej) 
+					continue;
+				av->flags |= AV_DEL;
+			}
+			ret = VM_HALTED; 
+			break;
+		  case OP_ACCTRESP:
+			for(av = vm->head[VM_REP]; av; av = av->next) {
+				if (av->i->spc->nr == C_DS_RAD_PKT && av->i->nr == C_DI_CODE) 
+					av->l = C_DV_CODE_ACCTRESP;
+				if (av->i->spc->nr != C_DS_RAD_ATR || av->i->keepacct) 
+					continue;
+				av->flags |= AV_DEL;
+			}
+			ret = VM_HALTED; 
+			break;
 
 		  case OP_NOP:
 		  case OP_POP:
@@ -394,7 +427,12 @@ int vm_run(VM *vm)
 		   * Boolean ops
 		   */
 
-		  case OP_NO:
+		  case OP_EXISTS:
+		  	meta_freeavdata(&R);
+			R.l = ! (R.flags & AV_UNRESOLVED);
+			R.p = 0; R.i = 0;
+			break;
+		  case OP_BOOLNOT:
 		  	meta_freeavdata(&R);
 			R.l = ! R.l; R.p = 0; R.i = 0;
 			break;
