@@ -13,6 +13,8 @@
  * History:
  * 2001/08/25 - EvB - Created
  * 2001/10/29 - EvB - Moved chan_put/getjob here as job_to/fromchan etc.
+ * 2003/06/23 - EvB - Fixed SIGSEGV caused by wrong arguments to log message
+ *		      when a shared queue overflows
  */
 
 char jobs_id[] = "JOBS - Copyright (C) 2001 Emile van Bergen.";
@@ -239,7 +241,7 @@ void job_toiface(IFACE *i, JOB *j, time_t t)
 	if (i->sendqlen >= C_MAX_SENDQLEN) {
 		msg(F_PROC, L_NOTICE, "job_toiface: Shared queue for interface "
 				      "%s overflowing (%d) - dropping job!\n",
-				      i->sendqlen);
+				      i->name, i->sendqlen);
 		job_del(j);
 		return;
 	}
