@@ -450,8 +450,10 @@ void sock_handle_read(struct radcfg *c, time_t t)
 
 	/* Attach response to query and reply to it */
 
-	r->query->rephead = head;
-	r->query->reptail = head;
+	if (head) head->prev = r->query->reptail;
+	if (r->query->reptail) r->query->reptail->next = head;
+	else r->query->rephead = head;
+	r->query->reptail = tail;
 	query_reply(c, r->query, rad_code);
 }
 
@@ -790,7 +792,7 @@ int fixup_query(struct radcfg *c, struct radquery *q)
 		av->l = c->nas_ip_address;
 		meta_addav(&q->reqhead, &q->reqtail, 0, 0, av);
 	}
-	if (q->missing & A_CHAP_CHAL) {
+	if (q->missing & A_CHAP_CHAL && c->noencpass == 0) {
 		av = safe_malloc(sizeof(META_AV));
 		memset(av, 0, sizeof(META_AV));
 		av->i = c->di_chap_chal;
